@@ -36,10 +36,10 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "6.1.1"
+#define SUNDIALS_VERSION "6.3.0"
 #define SUNDIALS_VERSION_MAJOR 6
-#define SUNDIALS_VERSION_MINOR 1
-#define SUNDIALS_VERSION_PATCH 1
+#define SUNDIALS_VERSION_MINOR 3
+#define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 #define SUNDIALS_GIT_VERSION ""
 
@@ -48,6 +48,9 @@
  * SUNDIALS build information
  * -----------------------------------------------------------------*/
 
+#define SUNDIALS_C_COMPILER_HAS_MATH_PRECISIONS
+#define SUNDIALS_C_COMPILER_HAS_ISINF_ISNAN
+#define SUNDIALS_C_COMPILER_HAS_INLINE
 
 /* Define precision of SUNDIALS data type 'realtype'
  * Depending on the precision level, one of the following
@@ -71,11 +74,10 @@
  */
 #define SUNDIALS_INDEX_TYPE int64_t
 
-/* Use generic math functions
- * If it was decided that generic math functions can be used, then
- *     #define SUNDIALS_USE_GENERIC_MATH
+/* Use std-c math functions
+ * DEPRECATED SUNDIALS_USE_GENERIC_MATH
  */
-#define SUNDIALS_USE_GENERIC_MATH
+/* #undef SUNDIALS_USE_GENERIC_MATH */
 
 /* Use POSIX timers if available.
  *     #define SUNDIALS_HAVE_POSIX_TIMERS
@@ -91,6 +93,18 @@
 /* BUILD SUNDIALS with profiling functionalities */
 /* #undef SUNDIALS_BUILD_WITH_PROFILING */
 
+/* BUILD SUNDIALS with logging functionalities */
+#define SUNDIALS_LOGGING_LEVEL 0
+
+/* BUILD SUNDIALS with MPI-enabled logging */
+/* #undef SUNDIALS_LOGGING_ENABLE_MPI */
+
+/* Is snprintf available? */
+#define SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
+#ifndef SUNDIALS_SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
+#define SUNDIALS_MAX_SPRINTF_SIZE 
+#endif
+
 /* ------------------------------------------------------------------
  * SUNDIALS TPL macros
  * -----------------------------------------------------------------*/
@@ -99,7 +113,7 @@
 /* #undef SUNDIALS_CALIPER_ENABLED */
 
 /* MAGMA backends */
-#define SUNDIALS_MAGMA_BACKENDS_CUDA
+/* #undef SUNDIALS_MAGMA_BACKENDS_CUDA */
 /* #undef SUNDIALS_MAGMA_BACKENDS_HIP */
 
 /* Set if SUNDIALS is built with MPI support, then
@@ -118,7 +132,7 @@
 /* #undef SUNDIALS_TRILINOS_HAVE_MPI */
 
 /* RAJA backends */
-#define SUNDIALS_RAJA_BACKENDS_CUDA
+/* #undef SUNDIALS_RAJA_BACKENDS_CUDA */
 /* #undef SUNDIALS_RAJA_BACKENDS_HIP */
 /* #undef SUNDIALS_RAJA_BACKENDS_SYCL */
 
@@ -198,10 +212,10 @@
 #endif
 
 #ifndef SUNDIALS_C_INLINE
-#ifndef __STDC_VERSION__ /* must be c89 or c90 */
-#define SUNDIALS_C_INLINE
-#else
+#ifdef SUNDIALS_C_COMPILER_HAS_INLINE
 #define SUNDIALS_C_INLINE inline
+#else
+#define SUNDIALS_C_INLINE
 #endif
 #endif
 
