@@ -195,7 +195,7 @@ int main(int argc, char *argv[])
 
   /* Create the SUNDIALS context object for this simulation. */
   SUNContext ctx = NULL;
-  SUNContext_Create(NULL, &ctx);
+  retval = SUNContext_Create(NULL, &ctx);
   if (check_retval(&retval, "SUNContext_Create", 1)) return 1;
 
   /*
